package de.intevation.flys.importer;

import java.sql.SQLException;
import java.util.List;

import org.apache.log4j.Logger;

import org.hibernate.Session;
import org.hibernate.Query;
import org.hibernate.exception.ConstraintViolationException;

import de.intevation.flys.model.DischargeZone;
import de.intevation.flys.model.FlowVelocityModel;
import de.intevation.flys.model.River;


public class ImportFlowVelocityModel {

    private static final Logger log =
        Logger.getLogger(ImportFlowVelocityModel.class);


    private String description;

    private ImportDischargeZone dischargeZone;

    private List<ImportFlowVelocityModelValue> values;

    private FlowVelocityModel peer;


    public ImportFlowVelocityModel(
        ImportDischargeZone dischargeZone,
        String              description
    ) {
        this.dischargeZone = dischargeZone;
        this.description   = description;
    }


    public void storeDependencies(River river)
    throws SQLException, ConstraintViolationException
    {
        log.debug("store dependencies");

        dischargeZone.storeDependencies(river);

        FlowVelocityModel peer = getPeer(river);

        for (ImportFlowVelocityModelValue value: values) {
            value.storeDependencies(peer);
        }
    }


    public FlowVelocityModel getPeer(River river) {
        if (peer == null) {
            Session session = ImporterSession.getInstance().getDatabaseSession();

            DischargeZone zone = dischargeZone.getPeer(river);

            Query query = session.createQuery(
                "from FlowVelocityModel where " +
                "   river:=river and " +
                "   dischargeZone=:dischargeZone"
            );

            query.setParameter("river", river);
            query.setParameter("dischargeZone", zone);

            List<FlowVelocityModel> model = query.list();

            if (model.isEmpty()) {
                peer = new FlowVelocityModel(river, zone);
                session.save(peer);
            }
            else {
                peer = model.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
